{% load fleetpings %}

<link
    rel="stylesheet"
    href="{% fleetpings_static 'fleetpings/css/fleetpings.min.css' %}"
    integrity="sha512-+QMniThtoDDcrG5vAFSSKJ5ZyxY1m08u0RPoZnw9lZ0ZAWrc4jlZA+9MAS5pZWIzTEJevJChut4aW99JCSvMow=="
    crossorigin="anonymous"
>
