{% load fleetpings %}

<script
    type="module"
    src="{% fleetpings_static 'fleetpings/js/fleetpings.min.js' %}"
    integrity="sha512-O59Q373ugA0vmm1mzvd28JSjVafqDZ5wTMaFpzywVbNiOvduUEkSIEcoOql48Wz2WkszcdPC90bk4mATjFIsaA=="
    crossorigin="anonymous"
></script>
